from mc.net.minecraft.level.tile.Tile import Tile

class StoneTile(Tile):

    def __init__(self, tiles, id_, tex):
        super().__init__(tiles, id_, tex)
